@@ -8,6 +8,7 @@
 import os
 import time
 import cgi
+import re
 
 import gtk
 import hildon
@@ -36,6 +37,7 @@ class fMMS_GUI(hildon.Program):
 		self._pushdir = self.config.get_pushdir()
 		self.ch = ContactH.ContactHandler()
 		self.osso_c = osso.Context("fMMS", self.config.get_version(), False)
+		self.osso_rpc = osso.Rpc(self.osso_c)
 	
 		if not os.path.isdir(self._mmsdir):
 			log.info("creating dir %s", self._mmsdir)
@@ -74,29 +76,30 @@ class fMMS_GUI(hildon.Program):
 		
 		self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, gtk.gdk.Pixbuf, str, str)
 		self.treeview = hildon.GtkTreeView(gtk.HILDON_UI_MODE_NORMAL)
-		self.treeview.set_model(self.liststore)
-		
+
 		icon_col = gtk.TreeViewColumn('Icon')
 		sender_col = gtk.TreeViewColumn('Sender')
 		placeholder_col = gtk.TreeViewColumn('Photo')
-		
-		self.add_buttons_liststore()
-		
+
 		self.treeview.append_column(icon_col)
 		self.treeview.append_column(sender_col)
 		self.treeview.append_column(placeholder_col)
-		
+
 		icon_col.pack_start(iconcell, False)
 		icon_col.set_attributes(iconcell, pixbuf=0)
 		sender_col.pack_start(textcell, True)
 		sender_col.set_attributes(textcell, markup=1)
 		placeholder_col.pack_end(photocell, False)
 		placeholder_col.set_attributes(photocell, pixbuf=2)
-		
+
 		#self.liststore_menu = self.liststore_mms_menu()
 		#self.treeview.tap_and_hold_setup(self.liststore_menu)
-		self.treeview.connect('hildon-row-tapped', self.show_mms)
-		
+		self.treeview.tap_and_hold_setup(self.liststore_mms_menu())
+		self.treeview.tap_and_hold_setup(None)
+		self.tapsignal = self.treeview.connect('hildon-row-tapped', self.show_mms)
+		self.treeview.connect('button-press-event', self.cb_button_press)
+		#self.treeview.connect('tap-and-hold', self.tap_n_hold_cb, "TAPANDHOLD")
+
 		mmsBox = gtk.HBox()
 		icon_theme = gtk.icon_theme_get_default()
 		envelopePixbuf = icon_theme.load_icon("general_sms_button", 48, 0)
@@ -112,17 +115,17 @@ class fMMS_GUI(hildon.Program):
 		
 		newMsgButton.add(mmsBox)
 		newMsgButton.connect('clicked', self.new_mms_button_clicked)
-		#newMsgButton.set_size_request(0, 0)
+
+		""" gets the newMsgButton on top of the treeview """
+		actionbox = self.treeview.get_action_area_box()
+		self.treeview.set_action_area_visible(True)
+		actionbox.add(newMsgButton)
 		
-		hugeBox = gtk.VBox()
-		hugeBox.pack_start(newMsgButton, False, False, 0)
-		#hugeBox.pack_start(self.treeview, True, True, 0)
 		pan.add(self.treeview)
-		hugeBox.pack_start(pan, True, True, 0)
 
 		align = gtk.Alignment(1, 1, 1, 1)
 		align.set_padding(2, 2, 10, 10)		
-		align.add(hugeBox)
+		align.add(pan)
 		
 		self.window.add(align)
 	
@@ -140,12 +143,33 @@ class fMMS_GUI(hildon.Program):
 			note.system_note_dialog(firstlaunchmessage , 'notice')
 			self.create_config_dialog()
 			self.config.set_firstlaunch(0)
-		
-		
+
+
+	def cb_tap_and_hold(self, widget, event):
+		#selection = self.treeview.get_selection()
+		#model, paths = selection.get_selected_rows()
+		#print "model paths", model, paths
+		#print "widget event data", widget, event, data
+		print "tap and hold"
+		return False
+
+	
+	""" need this to always have the current path """
+	def cb_button_press(self, widget, event):
+		try:
+			(self.curPath, tvcolumn, x, y) = self.treeview.get_path_at_pos(int(event.x), int(event.y))
+		except:
+			self.curPath = None
+		return False
+
 	def cb_on_focus(self, widget, event):
 		#(model, itera) = self.treeview.get_selection().get_selected()
 		self.liststore.clear()
+		self.treeview.freeze_child_notify()
+		self.treeview.set_model(None)
 		self.add_buttons_liststore()
+		self.treeview.set_model(self.liststore)
+		self.treeview.thaw_child_notify()
 		#pass
 		return True
 	
@@ -157,7 +181,6 @@ class fMMS_GUI(hildon.Program):
 			filename = args[0]
 			if self.cont.is_fetched_push_by_transid(filename):
 				hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
-				#banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Opening message")
 				self.force_ui_update()
 				viewer = fMMSViewer.fMMS_Viewer(filename)
 				hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
@@ -165,8 +188,8 @@ class fMMS_GUI(hildon.Program):
 			else:
 				return
 		elif method == 'open_gui':
-			self.liststore.clear()
-			self.add_buttons_liststore()
+			# this shouldnt be needed as the on-focus cb should activate
+			#self.cb_on_focus(None, None)
 			return
 		elif method == 'send_mms':
 			log.info("launching sender with args: %s", args)
@@ -212,7 +235,8 @@ class fMMS_GUI(hildon.Program):
 		dialog.set_logo(fmms_logo)                                   
 		dialog.set_comments('MMS send and receive support for Fremantle')                      
 		dialog.set_version(self.config.get_version())                                                
-		dialog.set_copyright("By Nick Leppänen Larsson (aka frals)")                    
+		dialog.set_copyright("By Nick Leppänen Larsson (aka frals)")
+		gtk.about_dialog_set_url_hook(lambda dialog, link: self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (link,)))
 		dialog.set_website("http://mms.frals.se/")                                  
 		dialog.connect("response", lambda d, r: d.destroy())                      
 		dialog.show() 
@@ -267,6 +291,8 @@ class fMMS_GUI(hildon.Program):
 		imgwidth_label = gtk.Label("Resize image width:")
 		imgwidth_label.set_width_chars(labelwidth)
 		self.imgwidth = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+		self.imgwidth.set_max_length(5)
+		self.imgwidth_signal = self.imgwidth.connect('insert_text', self.insert_resize_cb)
 		imgwidth_text = self.config.get_img_resize_width()
 		if imgwidth_text != None:
 			self.imgwidth.set_text(str(imgwidth_text))
@@ -295,6 +321,36 @@ class fMMS_GUI(hildon.Program):
 		dialog.destroy()
 		return ret
 
+		
+	""" from http://faq.pygtk.org/index.py?req=show&file=faq14.005.htp """
+	def insert_resize_cb(self, widget, text, length, *args):
+		# if you don't do this, garbage comes in with text
+		text = text[:length]
+		pos = widget.get_position()
+		# stop default emission
+		widget.emit_stop_by_name("insert_text")
+		signal = self.imgwidth_signal
+		gobject.idle_add(self.insert_nr_mod, widget, signal, text, pos)
+		
+		
+	""" from http://faq.pygtk.org/index.py?req=show&file=faq14.005.htp """
+	def insert_nr_mod(self, widget, signal, text, pos):
+		# the next three lines set up the text. this is done because we
+		# can't use insert_text(): it always inserts at position zero.
+		orig_text = widget.get_text()
+		#text = string.replace(text, " ", "<SPACE>")
+		pattern = re.compile('[!^\D]')
+		text = pattern.sub("", text)
+		new_text = orig_text[:pos] + text + orig_text[pos:]
+		# avoid recursive calls triggered by set_text
+		widget.handler_block(signal)
+		# replace the text with some new text
+		widget.set_text(new_text)
+		widget.handler_unblock(signal)
+		# set the correct position in the widget
+		widget.set_position(pos + len(text))
+
+
 
 	""" selector for apn """
 	def create_apn_selector(self):
@@ -358,8 +414,7 @@ class fMMS_GUI(hildon.Program):
                                 mtime = varlist['Time']
                                 # TODO: Remove date if date == today
                                 # TODO: get locale format?
-                                mtime = time.strptime(mtime, "%Y-%m-%d %H:%M:%S")
-                                mtime = time.strftime("%Y-%m-%d | %H:%M", mtime)
+                                mtime = self.cont.convert_timeformat(mtime, "%Y-%m-%d | %H:%M")
 
 				fname = varlist['Transaction-Id']
 				direction = self.cont.get_direction_mms(fname)
@@ -375,8 +430,8 @@ class fMMS_GUI(hildon.Program):
 					sender = "0000000"
 				
 				if direction == fMMSController.MSG_DIRECTION_OUT:
-					# TODO: Change to show receivers name
-					sender = "You"
+					sender = self.cont.get_mms_headers(varlist['Transaction-Id'])
+					sender = sender['To'].replace("/TYPE=PLMN", "")
 				
 				sendername = self.ch.get_name_from_number(sender)
 				photo = icon_theme.load_icon("general_default_avatar", 48, 0)
@@ -441,12 +496,13 @@ class fMMS_GUI(hildon.Program):
 
 	""" action on delete contextmenu click """
 	def liststore_delete_clicked(self, widget):
-		selection = self.treeview.get_selection()
-		(model, miter) = selection.get_selected()
-		print model, miter
+		if self.curPath == None:
+			return
+			
+		model = self.treeview.get_model()
+		miter = model.get_iter(self.curPath)
 		# the 4th value is the transactionid (start counting at 0)
 		filename = model.get_value(miter, 3)
-		print filename
 		
 		dialog = gtk.Dialog()
 		dialog.set_title("Confirm")
@@ -468,7 +524,7 @@ class fMMS_GUI(hildon.Program):
 	def liststore_mms_menu(self):
 		menu = gtk.Menu()
 		menu.set_property("name", "hildon-context-sensitive-menu")
-		
+
 		openItem = gtk.MenuItem("Delete")
 		menu.append(openItem)
 		openItem.connect("activate", self.liststore_delete_clicked)
