@@ -216,15 +216,8 @@ class fMMS_Viewer(hildon.Program):
                 namelabel.set_alignment(0, 0.5)
 
                 mtime = headerlist['Time']
-		try:
-			mtime = time.strptime(mtime)
-		except ValueError, e:
-			mtime = time.strptime(mtime, "%Y-%m-%d %H:%M:%S")
-		except Exception, e:
-			log.exception("%s %s", type(e), e)
-			pass
-			
-		mtime = time.strftime("%Y-%m-%d | %H:%M", mtime)
+		mtime = self.cont.convert_timeformat(mtime, "%Y-%m-%d | %H:%M")
+					
                 timestring = '<span foreground="#666666">' + mtime + "</span>"
                 timelabel = gtk.Label(timestring)
                 timelabel.set_use_markup(True)
@@ -280,8 +273,6 @@ class fMMS_Viewer(hildon.Program):
 				img.set_from_file(path + "/" + fname)
 				fullpath = path + "/" + fname
 				ebox.add(img)
-				## TODO: make this menu proper without this ugly
-				# args passing
 				menu = self.mms_img_menu(fullpath)
 				ebox.tap_and_hold_setup(menu)
 				container.add(ebox)
